package com.ruoyi.predict.mapper;

import com.ruoyi.predict.domain.WfDaEfPara;
import org.apache.ibatis.annotations.Param;

import java.util.List;

/**
 * WfDaEfParaMapper接口
 *
 * @author hlf
 * @date 2021-08-11
 */
public interface WfDaEfParaMapper {
    /**
     * 查询WfDaEfPara
     *
     * @param windplantNo WfDaEfParaID
     * @return WfDaEfPara
     */
    public WfDaEfPara selectWfDaEfParaById(@Param("windplantNo") Long windplantNo, @Param("modelNo") Long modelNo);

    /**
     * 查询WfDaEfPara列表
     *
     * @param wfDaEfPara WfDaEfPara
     * @return WfDaEfPara集合
     */
    public List<WfDaEfPara> selectWfDaEfParaList(WfDaEfPara wfDaEfPara);

    /**
     * 新增WfDaEfPara
     *
     * @param wfDaEfPara WfDaEfPara
     * @return 结果
     */
    public int insertWfDaEfPara(WfDaEfPara wfDaEfPara);

    /**
     * 修改WfDaEfPara
     *
     * @param wfDaEfPara WfDaEfPara
     * @return 结果
     */
    public int updateWfDaEfPara(WfDaEfPara wfDaEfPara);

    /**
     * 删除WfDaEfPara
     *
     * @param windplantNo WfDaEfParaID
     * @return 结果
     */
    public int deleteWfDaEfParaById(@Param("windplantNo") Long windplantNo, @Param("modelNo") Long modelNo);
}
